@@ -91,8 +91,10 @@ struct PROXYPOLICY_st
 
 typedef struct PROXYPOLICY_st PROXYPOLICY;
 
+#ifdef DECLARE_STACK_OF
 DECLARE_STACK_OF(PROXYPOLICY)
-DECLARE_ASN1_SET_OF(PROXYPOLICY)
+#endif
+DECLARE_ASN1_FUNCTIONS(PROXYPOLICY)
 
 /* functions */
 
@@ -100,10 +102,6 @@ DECLARE_ASN1_SET_OF(PROXYPOLICY)
 ASN1_METHOD * PROXYPOLICY_asn1_meth();
 #endif
 
-PROXYPOLICY * PROXYPOLICY_new();
-
-void PROXYPOLICY_free();
-
 PROXYPOLICY * PROXYPOLICY_dup(
     PROXYPOLICY *                       policy);
 
@@ -135,15 +133,6 @@ unsigned char * PROXYPOLICY_get_policy(
     PROXYPOLICY *                       policy,
     int *                               length);
 
-int i2d_PROXYPOLICY(
-    PROXYPOLICY *                       policy,
-    unsigned char **                    a);
-
-PROXYPOLICY * d2i_PROXYPOLICY(
-    PROXYPOLICY **                      policy,
-    unsigned char **                    a,
-    long                                length);
-
 X509V3_EXT_METHOD * PROXYPOLICY_x509v3_ext_meth();
 
 STACK_OF(CONF_VALUE) * i2v_PROXYPOLICY(
